# frozen_string_literal: true

module Segmentor
  # Receipt is generated when a notification is sent to a target.
  class Receipt < ActiveRecord::Base
    self.table_name = :segmentor_receipts
    store :metadata, accessors: %i[target_id session_id], coder: JSON

    belongs_to :segment, class_name: '::Segmentor::Segment'
    belongs_to :user

    validates :sent_at, presence: true

    def self.record_receipt(target, rendered_value = nil)
      receipt = ::Segmentor::Receipt.new
      receipt.segment = target.segment
      receipt.user_id = target.user_id
      receipt.target_id = target.id
      receipt.session_id = target.session_id
      receipt.rendered_value = rendered_value
      receipt.sent_at = Time.now.utc
      receipt.save!

      receipt
    end

    def next
      segment.receipts.where('id > ?', id).first
    end

    def prev
      segment.receipts.where('id < ?', id).last
    end
  end
end
